@@ -112,7 +112,46 @@ class GetJson():
         click.secho(f"Markdown file created at { sys.path[0] }/{self.hostname} {self.command}.md", fg='green')
 
     def csv_file(self, parsed_json):
-        supported_templates = ['acl','arp','bgp','dot1x','hsrp','interface','lldp','ntp','ospf','platform','routing','stp','vlan','vrf','show cdp neighbors','show ip interface brief']
+        supported_templates = ['acl',
+                            'arp',
+                            'bgp',
+                            'dot1x',
+                            'hsrp',
+                            'interface',
+                            'lldp',
+                            'ntp',
+                            'ospf',
+                            'platform',
+                            'routing',
+                            'stp',
+                            'vlan',
+                            'vrf',
+                            'show access-lists',
+                            'show bgp process vrf all',
+                            'show bgp sessions',
+                            'show cdp neighbors',
+                            'show cdp neighbors detail',
+                            'show environment',
+                            'show etherchannel summary',
+                            'show interfaces',
+                            'show interfaces status',
+                            'show interfaces trunk',
+                            'show interface',
+                            'show interface status',
+                            'show interface transceiver',
+                            'show inventory',
+                            'show ip arp',
+                            'show ip arp vrf all',
+                            'show ip interface brief',
+                            'show ip ospf',
+                            'show ip ospf database',
+                            'show ip ospf interface',
+                            'show ip ospf interface vrf all',
+                            'show ip ospf neighbor',
+                            'show ip ospf neighbor detail',
+                            'show ip ospf neighbors detail',
+                            'show ip ospf neighbors detail vrf all',
+                            'show port-channel summary']
         for template in supported_templates:
             if self.command == template:
                 template_dir = Path(__file__).resolve().parent
